==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CalloutLabelUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutLabelUpdatingEventArgsDescription } from "./CalloutLabelUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutLabelUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutLabelUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutLabelUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutLabelUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutLabelUpdatingEventArgsDescriptionMetadata.c(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutLabelUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
            a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("SeriesName", "String");
            a.item("LabelRef", "(w:Label,j:label,wf:Label)DataRef");
        }
        static d(a) {
            CalloutLabelUpdatingEventArgsDescriptionMetadata.b(a);
            a.ad("CalloutLabelUpdatingEventArgs", () => new CalloutLabelUpdatingEventArgsDescription());
            a.ac("CalloutLabelUpdatingEventArgs", CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutLabelUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutLabelUpdatingEventArgsDescriptionMetadata, 'CalloutLabelUpdatingEventArgsDescriptionMetadata');
    CalloutLabelUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutLabelUpdatingEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CalloutLabelUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutLabelUpdatingEventArgsDescription } from "./CalloutLabelUpdatingEventArgsDescription";
/**
 * @hidden
 */
export let CalloutLabelUpdatingEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CalloutLabelUpdatingEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CalloutLabelUpdatingEventArgsDescriptionMetadata.a == null) {
                CalloutLabelUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CalloutLabelUpdatingEventArgsDescriptionMetadata.c(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
            }
            if (a.k(CalloutLabelUpdatingEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
            SeriesDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("XValueRef", "(w:XValue,j:xValue,wf:XValue)DataRef");
            a.item("YValueRef", "(w:YValue,j:yValue,wf:YValue)DataRef");
            a.item("ItemRef", "(w:Item,j:item,wf:Item)DataRef");
            a.item("Series", "ExportedType:Series");
            a.item("SeriesName", "String");
            a.item("LabelRef", "(w:Label,j:label,wf:Label)DataRef");
        }
        static d(a) {
            CalloutLabelUpdatingEventArgsDescriptionMetadata.b(a);
            a.ae("CalloutLabelUpdatingEventArgs", () => new CalloutLabelUpdatingEventArgsDescription());
            a.ad("CalloutLabelUpdatingEventArgs", CalloutLabelUpdatingEventArgsDescriptionMetadata.a);
        }
    }
    CalloutLabelUpdatingEventArgsDescriptionMetadata.$t = markType(CalloutLabelUpdatingEventArgsDescriptionMetadata, 'CalloutLabelUpdatingEventArgsDescriptionMetadata');
    CalloutLabelUpdatingEventArgsDescriptionMetadata.a = null;
    return CalloutLabelUpdatingEventArgsDescriptionMetadata;
})();
